@@ -1,7 +1,7 @@
 package Minion::Backend::Storable;
 use Minion::Backend -base;
 
-our $VERSION = 6.081;
+our $VERSION = 6.101;
 
 use Sys::Hostname 'hostname';
 use Time::HiRes qw(time usleep);
@@ -161,7 +161,7 @@ sub repair {
   return;
 }
 
-sub reset { shift->_guard->_save({}) }
+sub reset { $_[0]->_guard->_save({} => $_[0]{file}) }
 
 sub retry_job {
   my ($self, $id, $retries, $options) = (shift, shift, shift, shift // {});
@@ -280,14 +280,15 @@ use Storable ();
 
 sub DESTROY {
   my $self = shift;
-  $self->_save($self->_data) if $self->{write};
+  $self->_save($self->_data => $self->{backend}->file) if $self->{write};
   flock $self->{lock}, LOCK_UN;
 }
 
 sub new {
   my $self = shift->SUPER::new(@_);
-  $self->_save({}) unless -f (my $file = $self->{backend}->file);
-  open $self->{lock}, '>', "$file.lock";
+  my $path = $self->{backend}->file;
+  $self->_save({} => $path) unless -f $path;
+  open $self->{lock}, '>', "$path.lock";
   flock $self->{lock}, LOCK_EX;
   return $self;
 }
@@ -332,7 +333,7 @@ sub _jobs { shift->_data->{jobs} //= {} }
 
 sub _load { Storable::retrieve($_[1]) }
 
-sub _save { Storable::store($_[1] => $_[0]{backend}->file) }
+sub _save { Storable::store($_[1] => $_[2]) }
 
 sub _workers { shift->_data->{workers} //= {} }
 
@@ -856,7 +857,7 @@ Hash reference with whatever status information the worker would like to share.
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2014 Sebastian Riedel.
+Copyright (c) 2014 L<Sebastian Riedel|https://github.com/kraih>.
 
 Copyright (c) 2015--2017 Sebastian Riedel & Nic Sandfield.
 
@@ -867,12 +868,12 @@ the terms of the Artistic License version 2.0.
 
 =over 2
 
-=item Manuel Mausz (manuelm@github)
+=item L<Manuel Mausz|https://github.com/manuelm>
 
-=item Nils Diewald (Akron@github)
+=item L<Nils Diewald|https://github.com/Akron>
 
 =back
 
 =head1 SEE ALSO
 
-L<Minion>, L<Minion::Backend::Pg>, L<Minion::Backend::SQLite>.
+L<Minion>, L<Minion::Backend::Sereal>, L<Minion::Backend::SQLite>.
